MethodChannelBooleanMathsFlutterSdk class
An implementation of BooleanMathsFlutterSdkPlatform that uses method channels to reach the native BooleanMaths SDK.
- Inheritance
-
- Object
- PlatformInterface
- BooleanMathsFlutterSdkPlatform
- MethodChannelBooleanMathsFlutterSdk
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flush(
{required Duration timeout}) → Future< bool> -
See BooleanMaths.flush.
override
-
getHelloMessage(
) → Future< String?> -
See BooleanMaths.getHelloMessage.
override
-
handleIntent(
) → Future< void> -
See BooleanMaths.handleIntent.
override
-
initialize(
{required String apiKey, required String pixelId, required bool isDebug, required String wrapperVersion}) → Future< void> -
See BooleanMaths.initialize.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
String eventName, {Map< String, Object?> ? properties}) → Future<void> -
See BooleanMaths.trackEvent.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited