BooleanMathsFlutterSdkPlatform class abstract

The interface every platform implementation of this plugin must satisfy.

The default MethodChannelBooleanMathsFlutterSdk talks to the native SDK over a method channel. Tests can swap instance for a fake.

Inheritance
  • Object
  • PlatformInterface
  • BooleanMathsFlutterSdkPlatform
Implementers

Constructors

BooleanMathsFlutterSdkPlatform()
Constructs a BooleanMathsFlutterSdkPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flush({required Duration timeout}) → Future<bool>
See BooleanMaths.flush.
getHelloMessage() → Future<String?>
See BooleanMaths.getHelloMessage.
handleIntent() → Future<void>
See BooleanMaths.handleIntent.
initialize({required String apiKey, required String pixelId, required bool isDebug, required String wrapperVersion}) → Future<void>
See BooleanMaths.initialize.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
trackEvent(String eventName, {Map<String, Object?>? properties}) → Future<void>
See BooleanMaths.trackEvent.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BooleanMathsFlutterSdkPlatform
The default instance of BooleanMathsFlutterSdkPlatform to use.
getter/setter pair